pub struct GlobalRateLimitLayer { /* private fields */ }Expand description
Fixed-window rate limit state: at most capacity requests per window.
Implementations
Sourceimpl GlobalRateLimitLayer
impl GlobalRateLimitLayer
Sourcepub fn new(capacity: u64, window: Duration) -> Self
pub fn new(capacity: u64, window: Duration) -> Self
Allow at most capacity requests per window globally, and per_ip per IP.
pub fn with_per_ip_capacity(self, per_ip_capacity: u64) -> Self
pub fn with_per_actor_capacity(self, per_actor_capacity: u64) -> Self
pub fn with_trusted_proxy_cidrs(self, cidrs: &[String]) -> Self
Sourcepub async fn snapshot(&self) -> ThrottleSnapshot
pub async fn snapshot(&self) -> ThrottleSnapshot
Snapshot current throttle statistics for admin observability.
Returns counts of throttled requests per-IP, per-actor, and globally within the current window, plus top offenders (up to 10 each).